/*******************************************************************************
* File Name: CLK2.h  
* Version 2.20
*
* Description:
*  This file contains Pin function prototypes and register defines
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_PINS_CLK2_H) /* Pins CLK2_H */
#define CY_PINS_CLK2_H

#include "cytypes.h"
#include "cyfitter.h"
#include "cypins.h"
#include "CLK2_aliases.h"

/* APIs are not generated for P15[7:6] */
#if !(CY_PSOC5A &&\
	 CLK2__PORT == 15 && ((CLK2__MASK & 0xC0) != 0))


/***************************************
*        Function Prototypes             
***************************************/    

/**
* \addtogroup group_general
* @{
*/
void    CLK2_Write(uint8 value);
void    CLK2_SetDriveMode(uint8 mode);
uint8   CLK2_ReadDataReg(void);
uint8   CLK2_Read(void);
void    CLK2_SetInterruptMode(uint16 position, uint16 mode);
uint8   CLK2_ClearInterrupt(void);
/** @} general */

/***************************************
*           API Constants        
***************************************/
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup driveMode Drive mode constants
     * \brief Constants to be passed as "mode" parameter in the CLK2_SetDriveMode() function.
     *  @{
     */
        #define CLK2_DM_ALG_HIZ         PIN_DM_ALG_HIZ
        #define CLK2_DM_DIG_HIZ         PIN_DM_DIG_HIZ
        #define CLK2_DM_RES_UP          PIN_DM_RES_UP
        #define CLK2_DM_RES_DWN         PIN_DM_RES_DWN
        #define CLK2_DM_OD_LO           PIN_DM_OD_LO
        #define CLK2_DM_OD_HI           PIN_DM_OD_HI
        #define CLK2_DM_STRONG          PIN_DM_STRONG
        #define CLK2_DM_RES_UPDWN       PIN_DM_RES_UPDWN
    /** @} driveMode */
/** @} group_constants */
    
/* Digital Port Constants */
#define CLK2_MASK               CLK2__MASK
#define CLK2_SHIFT              CLK2__SHIFT
#define CLK2_WIDTH              1u

/* Interrupt constants */
#if defined(CLK2__INTSTAT)
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup intrMode Interrupt constants
     * \brief Constants to be passed as "mode" parameter in CLK2_SetInterruptMode() function.
     *  @{
     */
        #define CLK2_INTR_NONE      (uint16)(0x0000u)
        #define CLK2_INTR_RISING    (uint16)(0x0001u)
        #define CLK2_INTR_FALLING   (uint16)(0x0002u)
        #define CLK2_INTR_BOTH      (uint16)(0x0003u) 
    /** @} intrMode */
/** @} group_constants */

    #define CLK2_INTR_MASK      (0x01u) 
#endif /* (CLK2__INTSTAT) */


/***************************************
*             Registers        
***************************************/

/* Main Port Registers */
/* Pin State */
#define CLK2_PS                     (* (reg8 *) CLK2__PS)
/* Data Register */
#define CLK2_DR                     (* (reg8 *) CLK2__DR)
/* Port Number */
#define CLK2_PRT_NUM                (* (reg8 *) CLK2__PRT) 
/* Connect to Analog Globals */                                                  
#define CLK2_AG                     (* (reg8 *) CLK2__AG)                       
/* Analog MUX bux enable */
#define CLK2_AMUX                   (* (reg8 *) CLK2__AMUX) 
/* Bidirectional Enable */                                                        
#define CLK2_BIE                    (* (reg8 *) CLK2__BIE)
/* Bit-mask for Aliased Register Access */
#define CLK2_BIT_MASK               (* (reg8 *) CLK2__BIT_MASK)
/* Bypass Enable */
#define CLK2_BYP                    (* (reg8 *) CLK2__BYP)
/* Port wide control signals */                                                   
#define CLK2_CTL                    (* (reg8 *) CLK2__CTL)
/* Drive Modes */
#define CLK2_DM0                    (* (reg8 *) CLK2__DM0) 
#define CLK2_DM1                    (* (reg8 *) CLK2__DM1)
#define CLK2_DM2                    (* (reg8 *) CLK2__DM2) 
/* Input Buffer Disable Override */
#define CLK2_INP_DIS                (* (reg8 *) CLK2__INP_DIS)
/* LCD Common or Segment Drive */
#define CLK2_LCD_COM_SEG            (* (reg8 *) CLK2__LCD_COM_SEG)
/* Enable Segment LCD */
#define CLK2_LCD_EN                 (* (reg8 *) CLK2__LCD_EN)
/* Slew Rate Control */
#define CLK2_SLW                    (* (reg8 *) CLK2__SLW)

/* DSI Port Registers */
/* Global DSI Select Register */
#define CLK2_PRTDSI__CAPS_SEL       (* (reg8 *) CLK2__PRTDSI__CAPS_SEL) 
/* Double Sync Enable */
#define CLK2_PRTDSI__DBL_SYNC_IN    (* (reg8 *) CLK2__PRTDSI__DBL_SYNC_IN) 
/* Output Enable Select Drive Strength */
#define CLK2_PRTDSI__OE_SEL0        (* (reg8 *) CLK2__PRTDSI__OE_SEL0) 
#define CLK2_PRTDSI__OE_SEL1        (* (reg8 *) CLK2__PRTDSI__OE_SEL1) 
/* Port Pin Output Select Registers */
#define CLK2_PRTDSI__OUT_SEL0       (* (reg8 *) CLK2__PRTDSI__OUT_SEL0) 
#define CLK2_PRTDSI__OUT_SEL1       (* (reg8 *) CLK2__PRTDSI__OUT_SEL1) 
/* Sync Output Enable Registers */
#define CLK2_PRTDSI__SYNC_OUT       (* (reg8 *) CLK2__PRTDSI__SYNC_OUT) 

/* SIO registers */
#if defined(CLK2__SIO_CFG)
    #define CLK2_SIO_HYST_EN        (* (reg8 *) CLK2__SIO_HYST_EN)
    #define CLK2_SIO_REG_HIFREQ     (* (reg8 *) CLK2__SIO_REG_HIFREQ)
    #define CLK2_SIO_CFG            (* (reg8 *) CLK2__SIO_CFG)
    #define CLK2_SIO_DIFF           (* (reg8 *) CLK2__SIO_DIFF)
#endif /* (CLK2__SIO_CFG) */

/* Interrupt Registers */
#if defined(CLK2__INTSTAT)
    #define CLK2_INTSTAT            (* (reg8 *) CLK2__INTSTAT)
    #define CLK2_SNAP               (* (reg8 *) CLK2__SNAP)
    
	#define CLK2_0_INTTYPE_REG 		(* (reg8 *) CLK2__0__INTTYPE)
#endif /* (CLK2__INTSTAT) */

#endif /* CY_PSOC5A... */

#endif /*  CY_PINS_CLK2_H */


/* [] END OF FILE */
