/*******************************************************************************
* File Name: main.c
*
* Version: 3.0
*
* Description:
*  This code example demonstrates USB HID interface class operation by 
*  implementing a 3-button mouse. When the code is run, the mouse cursor moves 
*  from the right to the left, and vice-versa.
*
*
* Related Document:
*  Device Class Definition for Human Interface Devices (HID)
*  Firmware Specification- Version 1.11
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation. All rights reserved.
* This software is owned by Cypress Semiconductor Corporation and is protected
* by and subject to worldwide patent and copyright laws and treaties.
* Therefore, you may use this software only as provided in the license agreement
* accompanying the software package from which you obtained this software.
* CYPRESS AND ITS SUPPLIERS MAKE NO WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
* WITH REGARD TO THIS SOFTWARE, INCLUDING, BUT NOT LIMITED TO, NONINFRINGEMENT,
* IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
*******************************************************************************/

#include <project.h>

#define USBFS_DEVICE        (0u)

#define MOUSE_ENDPOINT      (1u)
#define MOUSE_DATA_LEN      (64u)
#define Pixels				(240)
#define Bits				(256)//(256)
#define VERSION				0x40;

/* Mouse packet array: button, X, Y */
uint8 mouseData[MOUSE_DATA_LEN] = {0u};
uint8 bSNstring[16u] = {0x0Eu, 0x03u, 'F', 0u, 'W', 0u, 'S', 0u, 'N', 0u, '0', 0u, '1', 0u};


void TX_USB(int index);
void init_asic(void);
void write_config(int addr, int data);
void Delay(int time);
void Delay2(int time);

unsigned int pix_count=0;
unsigned int clk_counter = 0;
unsigned int New_Result[Bits];
int Pictures[3][256];
unsigned char Alg_Flag=0;
unsigned int char_counter = 0;
unsigned char VCSEL_Power = 70;

unsigned char Exposure = 13;
unsigned char Pic_Counts = 0;

unsigned int delay_time = 0;
unsigned int delay_time2 = 0;


/*******************************************************************************
* Define Interrupt service routine and allocate an vector to the Interrupt
********************************************************************************/
CY_ISR(Clk_Counter_ISR)
{
	/* Read Status register in order to clear the sticky Terminal Count (TC) bit 
	 * in the status register. Note that the function is not called, but rather 
	 * the status is read directly.
	 */
   	Timer_1_STATUS;
    
    clk_counter++;    
}

CY_ISR(ADC_Conversion)
{
	/* Read Status register in order to clear the sticky Terminal Count (TC) bit 
	 * in the status register. Note that the function is not called, but rather 
	 * the status is read directly.
	 */
    
    New_Result[pix_count]= CY_GET_REG16(ADC_SAR_1_SAR_WRK0_PTR);
	pix_count++;    
}


/*******************************************************************************
* Function Name: main
********************************************************************************
*
* Summary:
*  Wraps the OUT data coming from the host back to the host on a subsequent IN.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
int main()
{
    CyGlobalIntEnable;

    /* Set user-defined Serial Number string descriptor. */
    USBFS_SerialNumString(bSNstring);

    /* Start USBFS operation with 3-V operation. */
    USBFS_Start(USBFS_DEVICE, USBFS_3V_OPERATION);

    /* Wait for device to enumerate */
    while (0u == USBFS_GetConfiguration())
    {
    }

    /* Enumeration is done, load mouse endpoint. */
    USBFS_LoadInEP(MOUSE_ENDPOINT, mouseData, MOUSE_DATA_LEN);

    
    ReadOut_o_Write(1u);    //P0[3]
    Preset_o_Write(0u);     //P0[5]
    Config_o_Write(0u);     //P0[6]   
    
    
    
    
    init_asic();
    
    
    /* Enable the Interrupt component connected to Timer interrupt */
    isr_1_StartEx(Clk_Counter_ISR);
    ADC_SAR_1_IRQ_StartEx(ADC_Conversion);
    
    
	/* Start the components */
    Timer_1_Start();                //CLK_Counter
    
    
    
    //Vvcsel
    PWM_1_Start();
    PWM_1_WriteCompare(25);         //Vvcsel
    PWM_1_WritePeriod(100);
    
    
    
    LED1_Write(0x01);
    
    
	int cc;
	int cc2;
	static unsigned int Pic_Counter = 0;
	unsigned int State_Counter = 0;
	unsigned char Active_Exposure = 13;
    
    
    for(cc=0; cc<20; cc++)
    {
        for(cc2=0; cc2<256; cc2++)
            Pictures[2][cc2] = (cc2);
            
        TX_USB(0);
        
        clk_counter = 0;
        pix_count=0;
    }
    
    
    for(;;)
    {
        if(clk_counter < 5)
        {
            ReadOut_o_Write(1u);
        }
        else if(clk_counter < 10)
            ReadOut_o_Write(0u);
        else if(clk_counter < (Active_Exposure))		//Readout - controls the exposure time (Watch = 25, Garmin = 45)
        {
            
        }
        else if(clk_counter == (Active_Exposure))
            ReadOut_o_Write(1u);
        else if(clk_counter > 10000)
            clk_counter = 0;
        else if(clk_counter > (5+Active_Exposure))
        {
            if(pix_count >= Pixels)
            {
                if(Pic_Counter >= Pic_Counts)
                {
                    //Controls the VCSEL power
                    Active_Exposure = Exposure;
                    
                    for(cc=0; cc<239; cc++)
                        Pictures[2][cc+16+1] = (New_Result[cc+1]-New_Result[cc]);
                    
                    
                    unsigned int rest;

                    for(cc=0; cc<239; cc++)
                    {
                        if(Pictures[2][cc+16+1] > 125)
                        {
                            rest = Pictures[2][cc+16+1] - 125;
                            Pictures[2][cc+16+1] = 125;
                            Pictures[2][cc+16+2] += rest;
                        }
                        else if(Pictures[2][cc+16+1] < -125)
                        {
                            rest = Pictures[2][cc+16+1] + 125;
                            Pictures[2][cc+16+1] = -125;
                            Pictures[2][cc+16+2] += rest;
                        }
                    }
                    
                    
                    
                    
                    Pictures[2][16] = New_Result[0];
                    Pictures[2][15] = New_Result[0]>>8;
                    Pictures[2][14] = 0x01;
                    
                    for(cc=0; cc<14; cc++)
                        Pictures[2][cc] = cc;
                    
                    Pictures[2][4] = VERSION;
                    
                    
                    if(State_Counter == 0x00)
                    {
                        Pictures[2][4] = 0x04;
                        Pictures[2][14] = 0x00;
                    }
                    
                    
/*                    if(delay_time > 0)
                    {
                        for(cc=0; cc<delay_time2; cc++)
                            Delay2(delay_time);
                    }
*/                    
                    char_counter = 0;//1;
                    
                    Alg_Flag=1;
//                    PJOUT |= BIT4;	//Data_RDY
                    
                    Pic_Counter = 0;
                }
                else
                    Pic_Counter++;
                
                pix_count=0;
                
                if(1==Alg_Flag)
                {
                    State_Counter++;
                    
                    if(State_Counter == 10)
                    {
                        PWM_1_WriteCompare(0x00);
                        State_Counter = 0;
                    }
                    else
                    {
                        PWM_1_WriteCompare(VCSEL_Power);
                    }
                    
                    
                    TX_USB(0);
                    
                    
                    
/*                    if(delay_time > 0)
                    {
                        for(cc=0; cc<delay_time2; cc++)
                            Delay2(delay_time);
                    }
*/                    
/*                    if(cmnd188 != 0x00)
                    {
                        cmnd188 = 0x00;
                    }
*/                    
                    clk_counter = 0;
                    pix_count=0;
                    Alg_Flag=0;
                }
                else
                {
                    clk_counter = 0;
                    pix_count = 0;
                }
            }
        
        }
        
        
        
        
        
//        TX_USB(0);
    }
}
//---------------------------------------------------------------------------------

void TX_USB(int index)
{
    int run = 0;
    int i = 0;
    
    if(index == 0)
    {
        for(run=0; run<4; run++)
        {
            for(i=0; i<64; i++)
                mouseData[i] = Pictures[2][run*64+i];
            
            
            /* Wait for ACK before loading data. */
            while (0u == USBFS_GetEPAckState(MOUSE_ENDPOINT))
            {
            }
            
            /* Load endpoint with data after ACK has been received. */
            USBFS_LoadInEP(MOUSE_ENDPOINT, mouseData, MOUSE_DATA_LEN);
        }
    }
}
//---------------------------------------------------------------------------------

void init_asic(void)
{
	Delay(1000);

 	//Config_o
    Config_o_Write(1u);

/*
 	write_config(0x00,0x03);
 	write_config(0x01,0x03);
 	write_config(0x03,0x03);
 	write_config(0x04,0x03);
 	write_config(0x05,0x03);
 	write_config(0x06,0x02);
 	write_config(0x07,0x00);
 	//write_config(0x08,0x02);
 	write_config(0x0A,0x00);
 	write_config(0x0B,0x03);
 	write_config(0x0C,0x00);
 	write_config(0x0D,0x00);
 	write_config(0x0E,0x00);*/
 	//write_config(0x0F,0x01);
 	//write_config(0x10,0x00);
 	//write_config(0x12,0x00);

/* 	write_config(0x0A,0x00);
 	write_config(0x0B,0x03);
 	write_config(0x06,0x03);
*/ 	//write_config(0x08,0x03);
 	//write_config(0x0C,0x03);
	write_config(0x09,0x01);	//Enable top-row only



 	//Config_o
    Config_o_Write(0u);

 	Delay(100);
}
//---------------------------------------------------------------------------------

void Delay(int time)
{
	int delay_counter = 0;
	//delay_counter = 0;
	while(delay_counter < time)
		delay_counter++;
	delay_counter = 0;
}
//---------------------------------------------------------------------------------

void Delay2(int time)
{
/*	//int start = clk_counter;
	int stop = clk_counter + time;

	while(clk_counter < stop)
	{

	}
*/


	//unsigned int delay_counter = 0;
    int cc = 0;
	for(cc=0; cc<time; cc++)
	{
        CyDelay(100u);
	}
}
//---------------------------------------------------------------------------------

void write_config(int addr, int data)
{
	Delay(100);

	//Bit0 (R/W)
    ReadOut_o_Write(1);
	Preset_o_Write(1);
    Delay(100);
    ReadOut_o_Write(0);
    Delay(100);

 	//Bit1 (A4)
    ReadOut_o_Write(1);
 	//P1OUT &=~(BIT5);
 	if(((addr>>4) & 0x01) == 0x01)
        Preset_o_Write(1);
 	else
 		Preset_o_Write(0);
 	Delay(100);
    ReadOut_o_Write(0);
 	Delay(100);

 	//Bit2 (A3)
    ReadOut_o_Write(1);
 	if(((addr>>3) & 0x01) == 0x01)
 		Preset_o_Write(1);
 	else
 		Preset_o_Write(0);
 	Delay(100);
    ReadOut_o_Write(0);
 	Delay(100);

 	//Bit3 (A2)
    ReadOut_o_Write(1);
 	if(((addr>>2) & 0x01) == 0x01)
 		Preset_o_Write(1);
 	else
 		Preset_o_Write(0);
 	Delay(100);
    ReadOut_o_Write(0);
 	Delay(100);

 	//Bit4 (A1)
    ReadOut_o_Write(1);
 	if(((addr>>1) & 0x01) == 0x01)
 		Preset_o_Write(1);
 	else
 		Preset_o_Write(0);
 	Delay(100);
    ReadOut_o_Write(0);
 	Delay(100);

 	//Bit5 (A0)
    ReadOut_o_Write(1);
 	if(((addr>>0) & 0x01) == 0x01)
 		Preset_o_Write(1);
 	else
 		Preset_o_Write(0);
 	Delay(100);
    ReadOut_o_Write(0);
 	Delay(100);

 	//Bit6 (-)
    ReadOut_o_Write(1);
 	if(((data>>1) & 0x01) == 0x01)
 		Preset_o_Write(1);
 	else
 		Preset_o_Write(0);
 	Delay(100);
    ReadOut_o_Write(0);
 	Delay(100);

 	//Bit7 (-)
    ReadOut_o_Write(1);
 	if(((data>>0) & 0x01) == 0x01)
 		Preset_o_Write(1);
 	else
 		Preset_o_Write(0);
 	Delay(100);
    ReadOut_o_Write(0);
 	Delay(100);
    ReadOut_o_Write(1);
 	Delay(100);

 	Preset_o_Write(0);
 	Delay(1000);
}
//---------------------------------------------------------------------------------

/* [] END OF FILE */
